@@ -1,7 +1,7 @@
 import logging
 
-from .fileFormatter import FileFormatter
-from .cmdParser import CmdParser
+from fileFormatter import FileFormatter
+from cmdParser import CmdParser
 # import log
 
 
@@ -14,7 +14,7 @@ def run():
     FileFormatter(CmdParser.parse_arguments()).run()
 
 
-run()
+# run()
 
 # PositionConfig('default.editorconfig')
 
